@@ -1,6 +1,8 @@
 import base64
 import hashlib
 import os
+import time
+from datetime import datetime, timedelta
 from http.cookiejar import LWPCookieJar
 
 import requests
@@ -66,6 +68,14 @@ class irDataClient:
         if r.status_code == 401:
             # unauthorised, likely due to a timeout, retry after a login
             self.authenticated = False
+            return self._get_resource_or_link(url, payload=payload)
+
+        if r.status_code == 429:
+            print("Rate limited, waiting")
+            reset_datetime = datetime.fromtimestamp(r.header["x-ratelimit-reset"])
+            delta = reset_datetime - datetime.now()
+            time.sleep(delta.total_seconds())
+            return self._get_resource_or_link(url, payload=payload)
 
         if r.status_code != 200:
             raise RuntimeError(r.json())
@@ -268,7 +278,12 @@ class irDataClient:
             payload["team_id"] = team_id
 
         resource = self._get_resource("/data/results/lap_data", payload=payload)
-        return self._get_chunks(resource["chunk_info"])
+        if resource["chunk_info"]:
+            return self._get_chunks(resource["chunk_info"])
+        
+        # if there are no chunks to get, that's because no laps were done by this cust_id
+        # on this subsession, return an empty list for compatibility
+        return []
 
     def result_event_log(self, subsession_id=None, simsession_number=0):
         if not subsession_id:
